.bb-waterfall-view{flex:1;width:auto;overflow-x:auto;overflow-y:hidden}.bb-waterfall-view .header{position:relative;z-index:1;height:100px;line-height:100px;margin-bottom:2px;margin-right:-150px;vertical-align:middle}.bb-waterfall-view .header .header-content{height:100%;overflow:hidden}.bb-waterfall-view .header .header-content svg{width:100%;height:100%}.bb-waterfall-view .header .header-content .axis .domain{fill:none}.bb-waterfall-view .header .header-content .axis.x .tick a{text-decoration:none}.bb-waterfall-view .header .header-content .axis.x .tick text{fill:#3498db;font-size:12px}.bb-waterfall-view .header .header-content .axis.x .tick line{stroke-width:20px}.bb-waterfall-view .content{position:relative;height:100%}.bb-waterfall-view .content .inner-content{position:absolute;top:0;bottom:110px;overflow-y:auto;overflow-x:visible;width:100%}.bb-waterfall-view .content .inner-content .svg-container{position:relative;width:100%;height:16000px}.bb-waterfall-view .content .inner-content .svg-container svg{width:100%;height:100%}.bb-waterfall-view .content .inner-content .svg-container svg .chart .builder .build{cursor:pointer}.bb-waterfall-view .content .inner-content .svg-container svg .chart .builder .build rect,.bb-waterfall-view .content .inner-content .svg-container svg .chart .builder .build polygon{stroke:#3498db;stroke-width:1px}.bb-waterfall-view .content .inner-content .svg-container svg .chart .builder .build polygon{fill:#fff}.bb-waterfall-view .content .inner-content .svg-container svg .chart .builder .build .buildstep text{font-size:12px}.bb-waterfall-view .content .inner-content .svg-container svg .chart .builder text.id{fill:#3498db;font-size:12px;text-anchor:middle}.bb-waterfall-view .content .inner-content .svg-container svg .chart .builder circle{stroke:#3498db;stroke-width:1px}.bb-waterfall-view .content .inner-content .svg-container svg .axis .domain{fill:none}.bb-waterfall-view .content .inner-content .svg-container svg .axis.y .tick text{fill:#3498db;font-size:10px}.bb-waterfall-view .content .inner-content .svg-container svg .axis.y .tick line{stroke:#3498db;stroke-width:1px}.bb-waterfall-view .fill.results_SUCCESS{fill:#8d3}.bb-waterfall-view .fill.results_WARNINGS{fill:#fa3}.bb-waterfall-view .fill.results_FAILURE{fill:#e88}.bb-waterfall-view .fill.results_SKIPPED{fill:#ade}.bb-waterfall-view .fill.results_EXCEPTION{fill:#c6c}.bb-waterfall-view .fill.results_RETRY,.bb-waterfall-view .fill.results_CANCELLED{fill:#ecc}.bb-waterfall-view .fill.results_PENDING{fill:#e7d100}.bb-waterfall-view .fill.results_UNKNOWN{fill:#eee}.bb-waterfall-view .stroke.results_SUCCESS{stroke:#8d3}.bb-waterfall-view .stroke.results_WARNINGS{stroke:#fa3}.bb-waterfall-view .stroke.results_FAILURE{stroke:#e88}.bb-waterfall-view .stroke.results_SKIPPED{stroke:#ade}.bb-waterfall-view .stroke.results_EXCEPTION{stroke:#c6c}.bb-waterfall-view .stroke.results_RETRY,.bb-waterfall-view .stroke.results_CANCELLED{stroke:#ecc}.bb-waterfall-view .stroke.results_PENDING{stroke:#e7d100}.bb-waterfall-view .stroke.results_UNKNOWN{stroke:#eee}.svg-tooltip{pointer-events:none}
